Raspberry Pi ws2812 Library
===========================

Adapted from https://github.com/626Pilot/RaspberryPi-NeoPixel-WS2812

Changes:
* Adapted into a library for inclusion in both C and Python bindings
* Fixed the way brightness is applied to the buffer
* Added functions for setting up with a flexible number of pixels
